@@ -4,12 +4,12 @@
 # SPDX-License-Identifier: Apache-2.0
 
 set -xeuf -o pipefail
-
-find ../target/ -name "pkcs11_bindings.rs" -delete
+TARGET_DIR=${CARGO_TARGET_DIR:-../target}
+find "$TARGET_DIR" -name "pkcs11_bindings.rs" -delete
 MAKE_GENERIC_BINDINGS=1 cargo build --features generate-bindings
-find ../target/ -name "pkcs11_bindings.rs" | xargs -I '{}' cp '{}' src/bindings/generic.rs
+find "$TARGET_DIR" -name "pkcs11_bindings.rs" | xargs -I '{}' cp '{}' src/bindings/generic.rs
 
-targets="aarch64-unknown-linux-gnu arm-unknown-linux-gnueabi x86_64-pc-windows-msvc i686-unknown-linux-gnu powerpc64-unknown-linux-gnu x86_64-unknown-linux-gnu x86_64-apple-darwin aarch64-apple-darwin x86_64-unknown-freebsd"
+targets="aarch64-unknown-linux-gnu arm-unknown-linux-gnueabi loongarch64-unknown-linux-gnu x86_64-pc-windows-msvc i686-unknown-linux-gnu powerpc64-unknown-linux-gnu x86_64-unknown-linux-gnu x86_64-apple-darwin aarch64-apple-darwin x86_64-unknown-freebsd"
 TARGET_INSTALLED=
 
 for target in $targets; do
@@ -21,7 +21,7 @@ for target in $targets; do
     fi
 
     cargo build --target "$target" --features generate-bindings
-    find ../target/"$target"/ -name "pkcs11_bindings.rs" | xargs -I '{}' cp '{}' src/bindings/"$target".rs
+    find "$TARGET_DIR"/"$target"/ -name "pkcs11_bindings.rs" | xargs -I '{}' cp '{}' src/bindings/"$target".rs
 
     if [ "$TARGET_INSTALLED" == "$target" ]; then
         rustup target remove "$target"
